Interface: ScriptableLineSegmentContext | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ScriptableLineSegmentContext

## # Properties

### # datasetIndex

• datasetIndex: `number`

#### # Defined in

index.esm.d.ts:36
(opens new window)

### # p0

• p0: `PointElement`<`PointProps`, `PointOptions`>

#### # Defined in

index.esm.d.ts:32
(opens new window)

### # p0DataIndex

• p0DataIndex: `number`

#### # Defined in

index.esm.d.ts:34
(opens new window)

### # p1

• p1: `PointElement`<`PointProps`, `PointOptions`>

#### # Defined in

index.esm.d.ts:33
(opens new window)

### # p1DataIndex

• p1DataIndex: `number`

#### # Defined in

index.esm.d.ts:35
(opens new window)

### # type

• type: `"segment"`

#### # Defined in

index.esm.d.ts:31
(opens new window)